@@ -42,6 +42,8 @@ class AndroidLibrary(object):
         self._testserver_proc = None
         self._username = None
         self._password = None
+        self._calabash_bin_path = self._env_command(['calabash-android.bat',
+                                                     'calabash-android'])
 
     def _sdk_path(self, paths):
         for path in paths:
@@ -54,6 +56,14 @@ class AndroidLibrary(object):
             os.path.splitext(os.path.split(complete_path)[1])[0],
             os.path.split(complete_path)[0],))
 
+    def _env_command(self, commands):
+        for path in os.environ["PATH"].split(os.pathsep):
+            for command in commands:
+                exe_file = os.path.join(path, command)
+                if os.path.isfile(exe_file):
+                    return exe_file
+        raise AssertionError("Couldn't find binary %s" % os.path.commonprefix(commands))
+
     def _request(self, method, url, *args, **kwargs):
 
         if self._username is not None and self._password is not None:
@@ -320,7 +330,7 @@ class AndroidLibrary(object):
         Returns the package_name and the Main-Action
         from a given apk
         '''
-        rc, output, errput = self._execute_with_timeout(["calabash-android", "extract-manifest", apk])
+        rc, output, errput = self._execute_with_timeout([self._calabash_bin_path, "extract-manifest", apk])
         xmldoc = minidom.parseString(output)
         manifest = xmldoc.getElementsByTagName("manifest")
         assert len(manifest) > 0, "No <manifest> tag found in manifest file"
